@@ -31,11 +31,7 @@
 #include "konversation_state.h"
 
 #include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KIO/OpenUrlJob>
 #include <KConfig>
 #include <KShell>
@@ -43,9 +39,12 @@
 #include <KWallet>
 #include <KTextEdit>
 #include <KSharedConfig>
-#include <KStartupInfo>
 #include <KWindowSystem>
 
+#if HAVE_X11
+#include <KStartupInfo>
+#endif
+
 #include <QRegularExpression>
 #include <QDBusConnection>
 #include <QNetworkProxy>
@@ -54,9 +53,7 @@
 #include <QTextCursor>
 #include <QDesktopServices>
 #include <QCommandLineParser>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <QNetworkInformation>
-#endif
 
 using namespace Konversation;
 
@@ -105,9 +102,6 @@ Application::~Application()
     delete m_osd;
     m_osd = nullptr;
     closeWallet();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    delete m_networkConfigurationManager;
-#endif
     if (m_restartScheduled) implementRestart();
 }
 
@@ -158,18 +152,8 @@ void Application::createMainWindow(AutoConnectMode autoConnectMode, WindowRestor
     connect(m_connectionManager, &ConnectionManager::identityOffline, m_awayManager, &AwayManager::identityOffline);
     connect(m_connectionManager, &ConnectionManager::connectionChangedAwayState, m_awayManager, &AwayManager::updateGlobalAwayAction);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-// Silence deprecation warnings as long as there is no known substitute for QNetworkConfigurationManager
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-    m_networkConfigurationManager = new QNetworkConfigurationManager();
-    connect(m_networkConfigurationManager, &QNetworkConfigurationManager::onlineStateChanged, m_connectionManager, &ConnectionManager::onOnlineStateChanged);
-QT_WARNING_POP
-#else
     QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability);
     connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, m_connectionManager, &ConnectionManager::onOnlineStateChanged);
-#endif
 
     m_scriptLauncher = new ScriptLauncher(this);
 
@@ -222,7 +206,9 @@ QT_WARNING_POP
     else if (Preferences::self()->showTrayIcon() && Preferences::self()->hideToTrayOnStartup())
     {
         mainWindow->systemTrayIcon()->hideWindow();
+#if HAVE_X11
         KStartupInfo::appStarted();
+#endif
     }
     else
         mainWindow->show();
@@ -247,7 +233,7 @@ QT_WARNING_POP
             return left->sortIndex() < right->sortIndex();
         });
 
-        for (const auto& server : qAsConst(serversToAutoconnect)) {
+        for (const auto& server : std::as_const(serversToAutoconnect)) {
             m_connectionManager->connectTo(Konversation::CreateNewConnection, server->id());
         }
     }
@@ -400,7 +386,7 @@ void Application::dbusInfo(const QString& string)
 void Application::readOptions()
 {
     // read nickname sorting order for channel nick lists
-    KConfigGroup cgSortNicknames(KSharedConfig::openConfig()->group("Sort Nicknames"));
+    KConfigGroup cgSortNicknames(KSharedConfig::openConfig()->group(QStringLiteral("Sort Nicknames")));
 
     QString sortOrder=cgSortNicknames.readEntry("SortOrder");
     QStringList sortOrderList=sortOrder.split(QString());
@@ -480,7 +466,6 @@ void Application::readOptions()
         m_osd->setPalette(p);
     }
 
-    // Server list
     const QStringList groups = KSharedConfig::openConfig()->groupList().filter(
                                         QRegularExpression(QStringLiteral("ServerGroup [0-9]+")));
     QMap<int,QStringList> notifyList;
@@ -565,10 +550,11 @@ void Application::readOptions()
     // Quick Buttons List
 
     // if there are button definitions in the config file, remove default buttons
-    if (KSharedConfig::openConfig()->hasGroup("Button List"))
+    if (KSharedConfig::openConfig()->hasGroup(QStringLiteral("Button List"))) {
         Preferences::clearQuickButtonList();
+    }
 
-    KConfigGroup cgQuickButtons(KSharedConfig::openConfig()->group("Button List"));
+    KConfigGroup cgQuickButtons(KSharedConfig::openConfig()->group(QStringLiteral("Button List")));
     // Read all default buttons
     QStringList buttonList(Preferences::quickButtonList());
     // Read all quick buttons
@@ -583,10 +569,11 @@ void Application::readOptions()
     // Autoreplace List
 
     // if there are autoreplace definitions in the config file, remove default entries
-    if (KSharedConfig::openConfig()->hasGroup("Autoreplace List"))
+    if (KSharedConfig::openConfig()->hasGroup(QStringLiteral("Autoreplace List"))) {
         Preferences::clearAutoreplaceList();
+    }
 
-    KConfigGroup cgAutoreplace(KSharedConfig::openConfig()->group("Autoreplace List"));
+    KConfigGroup cgAutoreplace(KSharedConfig::openConfig()->group(QStringLiteral("Autoreplace List")));
     // Read all default entries
     QList<QStringList> autoreplaceList(Preferences::autoreplaceList());
     // Read all entries
@@ -624,13 +611,15 @@ void Application::readOptions()
         QString replace = cgAutoreplace.readEntry(replaceString + indexString, QString());
         if (!replace.isEmpty()) {
             int repLen=replace.length()-1;
-            if (replace.at(repLen)==QLatin1Char('#'))
+            if (replace.at(repLen)==QLatin1Char('#')) {
                 replace.truncate(repLen);
+            }
         }
         if (!pattern.isEmpty()) {
             int patLen=pattern.length()-1;
-            if (pattern.at(patLen)==QLatin1Char('#'))
+            if (pattern.at(patLen)==QLatin1Char('#')) {
                 pattern.truncate(patLen);
+                }
         }
         index++;
         indexString = QString::number(index);
@@ -657,7 +646,7 @@ void Application::readOptions()
     }
 
     // Ignore List
-    KConfigGroup cgIgnoreList(KSharedConfig::openConfig()->group("Ignore List"));
+    KConfigGroup cgIgnoreList(KSharedConfig::openConfig()->group(QStringLiteral("Ignore List")));
     // Remove all default entries if there is at least one Ignore in the Preferences::file
     if (cgIgnoreList.hasKey("Ignore0"))
         Preferences::clearIgnoreList();
@@ -669,13 +658,13 @@ void Application::readOptions()
     }
 
     // Aliases
-    KConfigGroup cgAliases(KSharedConfig::openConfig()->group("Aliases"));
+    KConfigGroup cgAliases(KSharedConfig::openConfig()->group(QStringLiteral("Aliases")));
     QStringList newList=cgAliases.readEntry("AliasList", QStringList());
     if (!newList.isEmpty())
         Preferences::self()->setAliasList(newList);
 
     // Channel Encodings
-    KConfigGroup cgEncodings(KSharedConfig::openConfig()->group("Encodings"));
+    KConfigGroup cgEncodings(KSharedConfig::openConfig()->group(QStringLiteral("Encodings")));
     const QMap<QString,QString> encodingEntries = cgEncodings.entryMap();
 
     const QRegularExpression reg(QStringLiteral("^([^\\s]+) ([^\\s]+)\\s?([^\\s]*)$"));
@@ -691,22 +680,24 @@ void Application::readOptions()
     }
 
     // Spell Checking Languages
-    KConfigGroup cgSpellCheckingLanguages(KSharedConfig::openConfig()->group("Spell Checking Languages"));
+    KConfigGroup cgSpellCheckingLanguages(KSharedConfig::openConfig()->group(QStringLiteral("Spell Checking Languages")));
     const QMap<QString, QString> spellCheckingLanguageEntries = cgSpellCheckingLanguages.entryMap();
 
     for (auto it = spellCheckingLanguageEntries.begin(), end = spellCheckingLanguageEntries.end(); it != end; ++it) {
         const QRegularExpressionMatch match = reg.match(it.key());
-        if (match.hasMatch())
+        if (!match.hasMatch()) {
+            continue;
+        }
+        if (match.captured(1) == QLatin1String("ServerGroup") && !match.captured(3).isEmpty())
         {
-            if (match.captured(1) == QLatin1String("ServerGroup") && !match.captured(3).isEmpty())
-            {
-                ServerGroupSettingsPtr serverGroup = Preferences::serverGroupById(sgKeys.at(match.captured(2).toInt()));
+            ServerGroupSettingsPtr serverGroup = Preferences::serverGroupById(sgKeys.at(match.captured(2).toInt()));
 
-                if (serverGroup)
-                    Preferences::setSpellCheckingLanguage(serverGroup, match.captured(3), it.value());
+            if (serverGroup) {
+                Preferences::setSpellCheckingLanguage(serverGroup, match.captured(3), it.value());
             }
-            else
-                Preferences::setSpellCheckingLanguage(match.captured(1), match.captured(2), it.value());
+        }
+        else {
+            Preferences::setSpellCheckingLanguage(match.captured(1), match.captured(2), it.value());
         }
     }
 
@@ -807,7 +798,7 @@ void Application::saveOptions(bool updateGUI)
     QStringList channelHistory;
     QHash<int, int> sgKeys;
 
-    for (const auto& serverGroup : qAsConst(sortedServerGroupMap)) {
+    for (const auto& serverGroup : std::as_const(sortedServerGroupMap)) {
         const Konversation::ServerList serverList = serverGroup->serverList();
         servers.clear();
         servers.reserve(serverList.size());
@@ -869,11 +860,11 @@ void Application::saveOptions(bool updateGUI)
         index++;
     }
 
-    KSharedConfig::openConfig()->deleteGroup("Server List");
+    KSharedConfig::openConfig()->deleteGroup(QStringLiteral("Server List"));
 
     // Ignore List
-    KSharedConfig::openConfig()->deleteGroup("Ignore List");
-    KConfigGroup cgIgnoreList(KSharedConfig::openConfig()->group("Ignore List"));
+    KSharedConfig::openConfig()->deleteGroup(QStringLiteral("Ignore List"));
+    KConfigGroup cgIgnoreList(KSharedConfig::openConfig()->group(QStringLiteral("Ignore List")));
     QList<Ignore*> ignoreList=Preferences::ignoreList();
     for (int i = 0; i < ignoreList.size(); ++i) {
         cgIgnoreList.writeEntry(QStringLiteral("Ignore%1").arg(i), QStringLiteral("%1,%2").arg(ignoreList.at(i)->getName()).arg(ignoreList.at(i)->getFlags()));
@@ -881,9 +872,9 @@ void Application::saveOptions(bool updateGUI)
 
     // Channel Encodings
     // remove all entries once
-    KSharedConfig::openConfig()->deleteGroup("Channel Encodings"); // legacy Jun 29, 2009
-    KSharedConfig::openConfig()->deleteGroup("Encodings");
-    KConfigGroup cgEncoding(KSharedConfig::openConfig()->group("Encodings"));
+    KSharedConfig::openConfig()->deleteGroup(QStringLiteral("Channel Encodings")); // legacy Jun 29, 2009
+    KSharedConfig::openConfig()->deleteGroup(QStringLiteral("Encodings"));
+    KConfigGroup cgEncoding(KSharedConfig::openConfig()->group(QStringLiteral("Encodings")));
     const QList<int> encServers = Preferences::channelEncodingsServerGroupIdList();
     //i have no idea these would need to be sorted //encServers.sort();
     for (int encServer : encServers) {
@@ -906,8 +897,8 @@ void Application::saveOptions(bool updateGUI)
     }
 
     // Spell Checking Languages
-    KSharedConfig::openConfig()->deleteGroup("Spell Checking Languages");
-    KConfigGroup cgSpellCheckingLanguages(KSharedConfig::openConfig()->group("Spell Checking Languages"));
+    KSharedConfig::openConfig()->deleteGroup(QStringLiteral("Spell Checking Languages"));
+    KConfigGroup cgSpellCheckingLanguages(KSharedConfig::openConfig()->group(QStringLiteral("Spell Checking Languages")));
 
     QHashIterator<Konversation::ServerGroupSettingsPtr, QHash<QString, QString> > i(Preferences::serverGroupSpellCheckingLanguages());
 
@@ -1212,14 +1203,10 @@ void Application::openUrl(const QString& url)
 #else
         auto *job = new KIO::OpenUrlJob(QUrl(url));
         job->setFollowRedirections(false);
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
         job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, Application::instance()->getMainWindow()));
-#else
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, Application::instance()->getMainWindow()));
-#endif
         job->start();
-#endif
         return;
+#endif
     }
 
     // Use custom browser
